#define QT_DBUS
#define QT_FREETYPE
#define QT_IMAGEFORMAT_PNG
#define QT_LIBINPUT
#define QT_LINKED_OPENSSL true
#define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE
#define QT_NO_CUPS
#define QT_NO_IMAGEFORMAT_JPEG
#define QT_NO_OPENGL_ES
#define QT_NO_OPENGL_ES_2
#define QT_OPENGL
#define QT_OPENSSL
#define QT_SSL
#define QT_WIDGETS
